package com.hello2morrow.sonargraph.languageprovider.java.command.system.scripts.core;

import static org.junit.Assert.assertEquals
import static org.junit.Assert.assertTrue

import com.hello2morrow.sonargraph.core.model.script.GroovyScript
import com.hello2morrow.sonargraph.core.model.script.ScriptMetricIdNode
import com.hello2morrow.sonargraph.core.model.script.ScriptMetricValueTreeNode
import com.hello2morrow.sonargraph.core.model.script.ScriptNamedTreeNode
import com.hello2morrow.sonargraph.core.model.script.ScriptTreeNode
import com.hello2morrow.sonargraph.languageprovider.java.command.system.scripts.AbstractJavaScriptTest
import com.hello2morrow.sonargraph.languageprovider.java.foundation.common.JavaTestFixture

public class PercentageCodeTooManyMethodsScriptTest extends AbstractJavaScriptTest
{
    private static final double TARGET_VALUE = 36.17376;
    private static final String PROJECT_PATH = JavaTestFixture.SCRIPT_PERCENTAGE_BASED_PROJECT_PATH;
    private static final String SCRIPT_PATH = JavaTestFixture.SCRIPT_PERCENTAGE_CODE_TOO_MANY_METHODS_SCRIPT_PATH;

    public PercentageCodeTooManyMethodsScriptTest()
    {
        super(PROJECT_PATH, SCRIPT_PATH);
    }

    @Override
    public void verifyResult(GroovyScript script)
    {
        ScriptNamedTreeNode metrics = script.getResultSet().getMetricRootNode();
        assertEquals("Wrong number of metrics", 1, metrics.getChildren().size());

        ScriptTreeNode metric = metrics.getChildren().get(0);
        assertEquals(
                "Wrong name",
                "Percentage of Statements in Classes with Many Methods (Percentage of statements in classes with more than 10 methods) [2]",
                metric.getName());
        assertTrue("Wrong class: " + metric.getClass().getName(), metric instanceof ScriptMetricIdNode);

        assertEquals("Wrong number of metric values", 2, metric.getChildren().size());

        ScriptMetricValueTreeNode value1 = (ScriptMetricValueTreeNode) metric.getChildren().get(0);
        assertEquals("Wrong value for module", TARGET_VALUE,  value1.getValue().doubleValue(), 0.0001);

        ScriptMetricValueTreeNode value2 = (ScriptMetricValueTreeNode) metric.getChildren().get(1);
        //System only has one module, therefore the two metric values must be the same.
        assertEquals("Wrong value for system", TARGET_VALUE, value2.getValue().doubleValue(), 0.0001);
    }
}
